Stan Math Library: stan/math/prim/scal/meta/length.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

length.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_META_LENGTH_HPP
2 #define STAN_MATH_PRIM_SCAL_META_LENGTH_HPP
3
4 #include <cstdlib>
5
6 namespace stan {
7
8 template <typename T>
9 size_t length(const T& /*x*/) {
10 return 1U;
11 }
12 }
13 #endif
14
stan
Definition: log_sum_exp.hpp:8
stan::length
size_t length(const std::vector< T > &x)
Definition: length.hpp:10

[ Stan Home Page ] © 2011–2016, Stan Development Team.